@@ -1,3 +1,136 @@
+package Bot::BasicBot::Pluggable::Module;
+use warnings;
+use strict;
+
+sub new {
+    my $class = shift;
+    my %param = @_;
+
+    my $name = ref($class) || $class;
+    $name =~ s/^.*:://;
+    $param{Name} ||= $name;
+
+    my $self = \%param;
+    bless $self, $class;
+
+    $self->init();
+
+    return $self;
+}
+
+sub config {
+    my ( $self, $config ) = @_;
+    for my $var ( keys %{$config} ) {
+        $self->set( $var, $config->{$var} ) unless defined( $self->get($var) );
+    }
+}
+
+sub bot {
+    my $self = shift;
+    return $self->{Bot};
+}
+
+sub store {
+    my $self = shift;
+    die "module has no bot" unless $self->bot;
+    return $self->bot->store;
+}
+
+sub get {
+    my $self = shift;
+    $self->store->get( $self->{Name}, @_ );
+}
+
+sub set {
+    my $self = shift;
+    $self->store->set( $self->{Name}, @_ );
+}
+
+sub unset {
+    my $self = shift;
+    $self->store->unset( $self->{Name}, @_ );
+}
+
+sub var {
+    my $self = shift;
+    my $name = shift;
+    if (@_) {
+        return $self->set( $name, shift );
+    }
+    else {
+        return $self->get($name);
+    }
+}
+
+sub store_keys {
+    my $self  = shift;
+    my $store = $self->store;
+
+    die "No store set up"   unless defined $store;
+    die "Store isn't a ref" unless ref($store);
+
+    $store->keys( $self->{Name}, @_ );
+}
+
+sub help {
+    my ( $self, $mess ) = @_;
+    return "No help for module '$self->{Name}'. This is a bug.";
+}
+
+sub say {
+    my $self = shift;
+    return $self->bot->say(@_);
+}
+
+sub reply {
+    my $self = shift;
+    return $self->bot->reply(@_);
+}
+
+sub tell {
+    my ( $self, $target, $body ) = @_;
+    if ( $target =~ /^#/ ) {
+        $self->say( { channel => $target, body => $body } );
+    }
+    else {
+        $self->say( { channel => 'msg', body => $body, who => $target } );
+    }
+}
+
+sub said {
+    my ( $self, $mess, $pri ) = @_;
+    $mess->{body} =~ s/(^\s*|\s*$)//g if defined $mess->{body};
+
+    my $handler = (qw/ seen admin told fallback /)[$pri];
+
+    return $self->$handler($mess);
+}
+
+sub authed {
+    my ( $self, $who ) = @_;
+    if ($self->bot->module('Auth')) {
+	 return $self->bot->module('Auth')->authed($who);
+    }
+    return 0;
+}
+
+
+sub init      { undef }
+sub connected { undef }
+sub chanjoin  { undef }
+sub chanpart  { undef }
+sub seen      { undef }
+sub admin     { undef }
+sub told      { undef }
+sub fallback  { undef }
+sub emoted    { undef }
+sub tick      { undef }
+sub stop      { undef }
+
+1;
+
+__END__
+
 =head1 NAME
 
 Bot::BasicBot::Pluggable::Module - base module for all BasicBot plugins
@@ -36,35 +169,12 @@ Don't use them as unchecked input data.
 
 =over 4
 
-=cut
-
-package Bot::BasicBot::Pluggable::Module;
-use warnings;
-use strict;
-
 =item new()
 
 Standard C<new> method, blesses a hash into the right class and puts any
 key/value pairs passed to it into the blessed hash. Calls C<init> to load
 any internal or user variables you may have set in your module.
 
-=cut
-
-sub new {
-    my $class = shift;
-    my %param = @_;
-
-    my $name = ref($class) || $class;
-    $name =~ s/^.*:://;
-    $param{Name} ||= $name;
-
-    my $self = \%param;
-    bless $self, $class;
-
-    $self->init();
-
-    return $self;
-}
 
 =item init()
 
@@ -72,9 +182,6 @@ Called as part of new class construction. May or may not be after
 server connection. Override this to do things when your module is added
 to the bot.
 
-=cut
-
-sub init { undef }
 
 =item config($config)
 
@@ -83,14 +190,6 @@ if it is not already defined in the module store. In that case the
 value from the store is used to initialise the variable. Typically
 called in the module's init functions.
 
-=cut
-
-sub config {
-	my ($self,$config) = @_;
-	for my $var (keys %{$config}) {
-		$self->set($var, $config->{$var}) unless defined($self->get($var));
-	}
-}
 
 =item start()
 
@@ -100,156 +199,80 @@ you're connected.
 
 TODO - this method not yet implemented.
 
-=cut
-
 =item stop()
 
 Called just before your module is removed from the bot. Do cleanup here.
 
-=cut
 
-sub stop { undef }
-
-=item bot
+=item bot()
 
 Returns the L<Bot::BasicBot::Pluggable> bot we're running under.
 
-=cut
-
-sub bot {
-    my $self = shift;
-    return $self->{Bot};
-}
 
 =item store
 
 Returns L<Bot::BasicBot::Pluggable::Store> subclass used to store variables.
 
-=cut
-
-sub store {
-  my $self = shift;
-  die "module has no bot" unless $self->bot;
-  return $self->bot->store;
-}
 
 =item get($name)
 
 Returns the value of a local variable from the object store.
 
-=cut
-
-sub get {
-    my $self = shift;
-    $self->store->get($self->{Name}, @_);
-}
 
 =item set($name => $value)
 
 Set a local variable into the object store.
 
-=cut
-
-sub set {
-    my $self = shift;
-    $self->store->set($self->{Name}, @_);
-}
 
 =item unset($name)
 
 Unsets a local variable - removes it from the store, not just C<undef>s it.
 
-=cut
-
-sub unset {
-    my $self = shift;
-    $self->store->unset($self->{Name}, @_);
-}
 
 =item var($name, [$value])
 
 C<get()> or C<set()> a local variable from the module store.
 
-=cut
-
-sub var {
-    my $self = shift;
-    my $name = shift;
-    if (@_) {
-        return $self->set($name, shift);
-    } else {
-        return $self->get($name);
-    }
-}
 
 =item store_keys
 
 Returns a list of all keys in the object store.
 
-=cut
-
-sub store_keys {
-    my $self = shift;
-    my $store = $self->store;
-
-    die "No store set up" unless defined $store;
-    die "Store isn't a ref" unless ref($store);
-	
-    $store->keys($self->{Name}, @_);
-}
 
 =item connected
 
 Called when the bot connects to the server. The return value is meaningless.
 
-=cut
-
-sub connected { undef }
 
 =item chanjoin($message)
 
 Called when a user joins a channel.
 
-=cut
-
-sub chanjoin { undef }
-
-=item chanpart($message)
-
-Called when a user leaves a channel.
-
-=cut
-
-sub chanpart { undef }
 
 =item userquit($message)
 
 Called when a user client quits. See L<Bot::BasicBot> for a description
 of the arguments.
 
-=cut
+=item chanpart($message)
+
+Called when a user leaves a channel.
 
 =item topic($message)
 
 Called when the topic of a channel is changed. See L<Bot::BasicBot> for a description
 of the arguments.
 
-=cut
-
 =item kicked($message)
 
 Called when a user is kicked from a channel. See L<Bot::BasicBot> for a description
 of the arguments.
 
-=cut
-
 =item nick_change($message)
 
 When a user changes nicks, this will be called. See L<Bot::BasicBot> for a description
 of the arguments.
 
-=cut
-
 =item help
 
 Called when a user asks for help on a topic and thus should return some useful
@@ -258,39 +281,18 @@ the bot will return a list of modules. Asking the bot 'help <modulename>' will
 call the C<help> function of that module, passing in the first parameter the
 message object that represents the question.
 
-=cut
-
-sub help {
-    my ($self, $mess) = @_;
-    return "No help for module '$self->{Name}'. This is a bug.";
-}
-
 =item say($message)
 
 Passing through L<Bot::BasicBot>, send messages without replying to a C<said()>:
 
   $self->say({ who => 'tom', body => 'boo', channel => 'msg' });
 
-=cut
-
-sub say {
-  my $self = shift;
-  return $self->bot->say(@_);
-}
-
 =item reply($message, $body)
 
 Replies to the given message with the given text. Another passthrough to
 C<Bot::BasicBot>. The message is used to pre-populate the reply, so it'll
 be in the same channel as the question, directed to the right user, etc.
 
-=cut
-
-sub reply {
-  my $self = shift;
-  return $self->bot->reply(@_);
-}
-
 =item tell($nick | $channel, $message)
 
 Convenience method to send message to nick (privmsg) or channel (public):
@@ -298,18 +300,6 @@ Convenience method to send message to nick (privmsg) or channel (public):
   $self->tell('tom', "hello there, fool");
   $self->tell('#sailors', "hello there, sailor");
 
-=cut
-
-sub tell {
-  my $self = shift;
-  my $target = shift;
-  my $body = shift;
-  if ($target =~ /^#/) {
-    $self->say({ channel => $target, body => $body });
-  } else {
-    $self->say({ channel => 'msg', body => $body, who => $target });
-  }
-}
 
 =item said($message, $priority)
 
@@ -343,17 +333,6 @@ in order - this will lead to nicer code. This approach is new, though, which
 is why it's not yet used in most of the shipped modules yet. It will eventually
 become the only thing to do, and I will deprecate C<said()>.
 
-=cut
-
-sub said {
-  my ($self, $mess, $pri) = @_;
-  $mess->{body} =~ s/(^\s*|\s*$)//g if defined $mess->{body};
-
-  my $handler = ( qw/ seen admin told fallback / )[$pri];
-
-  return $self->$handler($mess);
-  return undef;
-}
 
 =item replied($message,$reply)
 
@@ -367,61 +346,44 @@ is mainly meant to log the bots activity.
 
 Like C<said()>; called if you don't override C<said()>, but only for priority 0.
 
-=cut
-
-sub seen { undef }
 
 =item admin($message)
 
 Like C<said()>; called if you don't override C<said()>, but only for priority 1.
 
-=cut
-
-sub admin { undef }
 
 =item told($message)
 
 Like C<said()>; called if you don't override C<said()>, but only for priority 2.
 
-=cut
-
-sub told { undef }
-
 =item fallback($message)
 
 Like C<said()>; called if you don't override C<said()>, but only for priority 3.
 
-=cut
-
-sub fallback { undef }
-
 =item emoted($message, $priority)
 
 Called when a user emotes something in channel.
 
-=cut
-
-sub emoted { undef }
-
 =item tick
 
 Called every five seconds. It is probably worth having a counter and not
 responding to every single one, assuming you want to respond at all. The
 return value is ignored.
 
+=item authed($who)
+
+This is a convinient method that trys to check for the users
+authentication level via Auth.pm. It is exactly equivalent to
+
+    $self->bot->module('Auth')
+      and $self->bot->module('Auth')->authed($who);
+
+
 =back
 
-=cut
-
-sub tick { undef }
-
 =head1 AUTHOR
 
 Mario Domgoergen <mdom@cpan.org>
 
 This program is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
-
-=cut
-
-1;
