@@ -1,40 +1,3 @@
-=head1 NAME
-
-Bot::BasicBot::Pluggable::Module::Join - join and leave channels; remembers state
-
-=head1 IRC USAGE
-
-=over 4
-
-=item join <channel>
-
-=item part <channel>
-
-=item channels
-
-List the channels the bot is in.
-
-=back
-
-=head1 METHODS
-
-=over 4
-
-=item add_channel($channel)
-
-=item remove_channel($channel)
-
-=back
-
-=head1 AUTHOR
-
-Mario Domgoergen <mdom@cpan.org>
-
-This program is free software; you can redistribute it
-and/or modify it under the same terms as Perl itself.
-
-=cut
-
 package Bot::BasicBot::Pluggable::Module::Join;
 use base qw(Bot::BasicBot::Pluggable::Module);
 use warnings;
@@ -117,3 +80,43 @@ sub remove_channel {
 }
 
 1;
+
+__END__
+
+=head1 NAME
+
+Bot::BasicBot::Pluggable::Module::Join - join and leave channels; remembers state
+
+=head1 IRC USAGE
+
+=over 4
+
+=item join <channel>
+
+=item part <channel>
+
+=item channels
+
+List the channels the bot is in.
+
+=back
+
+=head1 METHODS
+
+=over 4
+
+=item add_channel($channel)
+
+=item remove_channel($channel)
+
+=back
+
+=head1 AUTHOR
+
+Mario Domgoergen <mdom@cpan.org>
+
+This program is free software; you can redistribute it
+and/or modify it under the same terms as Perl itself.
+
+
+
