@@ -1,37 +1,6 @@
-=head1 NAME
-
-Bot::BasicBot::Pluggable::Store::Deep - use DBM::Deep to provide a storage backend
-
-=head1 SYNOPSIS
-
-  my $store = Bot::BasicBot::Pluggable::Store::Deep->new(
-    file => "filename"
-  );
-
-  $store->set( "namespace", "key", "value" );
-
-=head1 DESCRIPTION
-
-This is a C<Bot::BasicBot::Pluggable::Store> that uses C<DBM::Deep> to store
-the values set by modules.
-
-=head1 AUTHOR
-
-Simon Wistow <simon@thegestalt.org>
-
-=head1 COPYRIGHT
-
-Copyright 2005, Simon Wistow
-
-This program is free software; you can redistribute it
-and/or modify it under the same terms as Perl itself.
-
-=cut
-
 package Bot::BasicBot::Pluggable::Store::Deep;
 use warnings;
 use strict;
-use Carp qw( croak );
 use DBM::Deep;
 
 use base qw( Bot::BasicBot::Pluggable::Store );
@@ -39,7 +8,7 @@ use base qw( Bot::BasicBot::Pluggable::Store );
 sub init {
     my $self = shift;
     delete $self->{type};
-    croak "You must pass a filename" unless defined $self->{file};
+    $self->{file} ||= 'bot-basicbot.deep';
     $self->{_db} = DBM::Deep->new(%$self) || die "Couldn't connect to DB '$self->{file}'";
 }
 
@@ -74,3 +43,35 @@ sub namespaces {
 
 1;
 
+__END__
+
+=head1 NAME
+
+Bot::BasicBot::Pluggable::Store::Deep - use DBM::Deep to provide a storage backend
+
+=head1 SYNOPSIS
+
+  my $store = Bot::BasicBot::Pluggable::Store::Deep->new(
+    file => "filename"
+  );
+
+  $store->set( "namespace", "key", "value" );
+
+=head1 DESCRIPTION
+
+This is a C<Bot::BasicBot::Pluggable::Store> that uses C<DBM::Deep> to store
+the values set by modules.
+
+=head1 AUTHOR
+
+Simon Wistow <simon@thegestalt.org>
+
+=head1 COPYRIGHT
+
+Copyright 2005, Simon Wistow
+
+This program is free software; you can redistribute it
+and/or modify it under the same terms as Perl itself.
+
+
+
